pub enum BaseAttributeCommand {
Get(Option<NotNan<f32>>),
Set(NotNan<f32>),
Reset,
}Variants
Get(Option<NotNan<f32>>)
Returns the base value of the specified attribute.
Set(NotNan<f32>)
Overwrites the base value of the specified attribute with the given value.
Reset
Resets the base value of the specified attribute to its default value.