pub enum ModifierAttributeCommand {
Add(ResourceLocation, NotNan<f32>, AttributeAddModifier),
Remove(ResourceLocation),
Get(ResourceLocation, Option<NotNan<f32>>),
}Variants
Add(ResourceLocation, NotNan<f32>, AttributeAddModifier)
Adds an attribute modifier with the specified properties if no modifier with the same ID already existed.
Remove(ResourceLocation)
Removes the attribute modifier with the specified ID.
Get(ResourceLocation, Option<NotNan<f32>>)
Returns the value of the modifier with the specified ID.