pub enum BossbarSetType {
Color(BossbarColor),
Max(i32),
Name(SNBT),
Players(Option<EntitySelector>),
Style(BossbarStyle),
Value(i32),
Visible(bool),
}Variants
Color(BossbarColor)
Set the text color (if no color was specified as part of a text component) and bar color. Defaults to white upon creation.
Max(i32)
Set the bossbar’s maximum value. Defaults to 100 upon creation.
Name(SNBT)
Set the bossbar’s name.
Players(Option<EntitySelector>)
Change the set of players to whom the bar is visible. Defaults to none upon creation.
Style(BossbarStyle)
Set the bossbar’s visual amount of segments: continuous, 6 segments, 10 segments, 12 segments, or 20 segments. Defaults to progress upon creation.
Value(i32)
Set the bossbar’s current value. Defaults to 0 upon creation.
Visible(bool)
Set the bossbar’s visibility. Defaults to true upon creation.