pub enum AdvancementCommand {
Everything,
Only(ResourceLocation, Option<String>),
From(ResourceLocation),
Through(ResourceLocation),
Until(ResourceLocation),
}Variants
Everything
Adds or removes all loaded advancements.
Only(ResourceLocation, Option<String>)
Adds or removes a single advancement or criterion.
From(ResourceLocation)
Adds or removes an advancement and all its child advancements.
Think of specifying everything from that advancement to the end.
The exact order the operation is carried out in is specified advancement > child > child's child > ... When it operates on a child that branches, it iterates through all its children before continuing.
Through(ResourceLocation)
Specifies an advancement, and adds or removes all its parent advancements, and all its child advancements.
Think of specifying everything through the specified advancement, going both backward and forward.
The exact order the operation is as if the command were executed with “until” specified, then with “from” specified: parent > parent's parent > ... > root > specified advancement > child > child's child > ...
Until(ResourceLocation)
Adds or removes an advancement and all its parent advancements until the root for addition/removal.
Think of specifying everything from the start until that advancement.
The exact order the operation is carried out in is: parent > parent's parent > ... > root > specified advancement.